@@ -243,6 +243,9 @@ def exception_handler(func: Callable[..., Any]) -> Callable[..., Any]:  # type:
         try:
             func(*args, **kwargs)
         except Exception as e:
+            debug = os.getenv(key="DEBUG_MQL", default=False)
             click.echo(f"\nERROR: {str(e)}")
+            if debug:
+                raise e
 
     return wrapper
