@@ -11,7 +11,9 @@ from typing import Dict, List, Optional
 from log_symbols import LogSymbols
 from packaging.version import parse
 from termcolor import colored
-from update_checker import UpdateChecker  # type: ignore
+from update_checker import UpdateChecker
+
+from ..interfaces import DWValidationType
 
 from .cli_context import CLIContext
 from .cli_utils import (
@@ -803,6 +805,52 @@ def list_queries(
             click.echo(f"• query_id={q.id}, status={q.status.value}")
 
 
+def _run_dw_validations(config: CLIContext, type: DWValidationType, model_id: Optional[int] = None) -> List[str]:
+    """Helper handles the calling of data warehouse issue generating functions"""
+
+    spinner = Halo(
+        text=f"Validating {type.name.lower()} elements on model {model_id} against data warehouse...", spinner="dots"
+    )
+    spinner.start()
+    issues = config.mql.get_data_warehouse_issues(type=type, model_key_id=model_id)
+    if issues is not None and len(issues) == 0:
+        spinner.succeed(
+            f"🎉 Finished validating {type.name.lower()} elements on model {model_id} against data warehouse, no issues found"
+        )
+    else:
+        spinner.fail(
+            f"😬 Issues found when validating {type.name.lower()} elements on model {model_id} against data warehouse"
+        )
+    return issues
+
+
+def _data_warehouse_validations_runner(config: CLIContext, model_id: Optional[int] = None) -> bool:
+    """Helper which calls the individual data warehouse validations to run and prints collected issues"""
+    # the only reason we do this is so that the model id is available in terminal output
+    if model_id is None and config.current_model is not None:
+        model_id = config.current_model.id
+
+    issues: List[str] = []
+    issues += _run_dw_validations(config=config, type=DWValidationType.DATA_SOURCE, model_id=model_id)
+    issues += _run_dw_validations(config=config, type=DWValidationType.DIMENSION, model_id=model_id)
+
+    # TODO: Even though we are about to have feature flagging on the mql_query server, only bring
+    # this back once metric dw validations don't cause priming
+    # issues += _run_dw_validations(config=config, type=DWValidationType.METRIC, model_id=model_id)
+
+    print(colored("\n".join(issues), "red"))
+    return len(issues) == 0
+
+
+@cli.command()
+@click.option("--model-id", type=int, required=False, help="Specific model id to run")
+@pass_config
+@exception_handler
+def data_warehouse_validations(config: CLIContext, model_id: Optional[int] = None) -> None:
+    """Run data warehouse validations for a model, defaults to current model"""
+    _data_warehouse_validations_runner(config=config, model_id=model_id)
+
+
 @cli.command()
 @config_validation_options
 @click.option(
@@ -825,15 +873,7 @@ def validate_configs(config: CLIContext, config_dir: str, skip_dw: bool = False)
     )
 
     if not skip_dw:
-        spinner_dw = Halo(text=f"Running data warehouse validations for configs in '{config_dir}'...", spinner="dots")
-        spinner_dw.start()
-        issues = config.mql.validate_model_against_data_warehouse(model.id)
-        if issues is not None and len(issues) == 0:
-            spinner_dw.succeed(f"🎉 Successfully validated model {model.id} against data warehouse, no issues found")
-        else:
-            spinner_dw.fail(f"😬 Issues found when validating model {model.id} against data warehouse")
-            print(colored("\n".join(issues), "red"))
-            return None
+        _data_warehouse_validations_runner(config=config, model_id=model.id)
 
 
 @cli.command()
@@ -867,15 +907,9 @@ def commit_configs(
     )
 
     if not skip_dw:
-        spinner_dw = Halo(text=f"Running data warehouse validations for configs in '{config_dir}'...", spinner="dots")
-        spinner_dw.start()
-        issues = config.mql.validate_model_against_data_warehouse(model.id)
-        if issues is not None and len(issues) == 0:
-            spinner_dw.succeed(f"🎉 Successfully validated model {model.id} against data warehouse, no issues found")
-        else:
-            spinner_dw.fail(f"😬 Issues found when validating model {model.id} against data warehouse")
-            print(colored("\n".join(issues), "red"))
-            return None
+        success = _data_warehouse_validations_runner(config=config, model_id=model.id)
+        if not success:
+            return
 
     if force_primary:
         promote_spinner = Halo(text="Promoting commited model to be primary", spinner="dots")
