@@ -400,6 +400,8 @@ class BackendInterface(BaseInterface):  # noqa: D
                         description
                         displayName
                         tier
+                        valueFormat
+                        isAdditive
                         userOwners{
                             user {
                                 userName
