@@ -196,6 +196,8 @@ class Metric:
     display_name: Optional[str] = None
     description: Optional[str] = None
     tier: Optional[int] = None
+    value_format: Optional[str] = None
+    is_additive: Optional[bool] = None
 
     @classmethod
     def from_gql_dict(cls, _input: Dict[str, Any]) -> "Metric":  # type: ignore [misc] # noqa: D
@@ -213,6 +215,8 @@ class Metric:
         self.description = metadata["description"]
         self.display_name = metadata["displayName"]
         self.tier = metadata["tier"]
+        self.value_format = metadata["valueFormat"]
+        self.is_additive = metadata["isAdditive"]
         self.team_owners = [TeamOwner.from_gql_dict(t["team"]) for t in metadata["teamOwners"]]
         self.user_owners = [UserOwner.from_gql_dict(u["user"]) for u in metadata["userOwners"]]
 
